@@ -121,6 +121,9 @@ static void addressbook_view_init	(AddressbookView      *view);
 static void addressbook_view_class_init	(AddressbookViewClass *klass);
 static void addressbook_view_dispose    (GObject *object);
 
+static ESource *find_first_source  (ESourceList *source_list);
+static ESource *get_primary_source (AddressbookView *view);
+
 typedef struct {
 	GtkWidget *editor;
 	char *uid;
@@ -179,7 +182,7 @@ delete_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
 	if (v)
-		eab_view_delete_selection(v);
+		eab_view_delete_selection(v, TRUE);
 }
 
 static void
@@ -551,11 +554,14 @@ source_list_changed_cb (ESourceList *source_list, AddressbookView *view)
 
 static void
 load_uri_for_selection (ESourceSelector *selector,
-			AddressbookView *view)
+			AddressbookView *view,
+			gboolean force)
 {
 	ESource *selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (selector));
+	ESource *primary = get_primary_source (view);
 
-	if (selected_source != NULL)
+	if (selected_source != NULL && 
+	    ((primary && (!g_str_equal (e_source_peek_uid (primary),e_source_peek_uid (selected_source) )))||force))
 		activate_source (view, selected_source);
 }
 
@@ -749,7 +755,7 @@ static void
 primary_source_selection_changed_callback (ESourceSelector *selector,
 					   AddressbookView *view)
 {
-	load_uri_for_selection (selector, view);
+	load_uri_for_selection (selector, view, FALSE);
 	save_primary_selection (view);
 }
 
@@ -1078,6 +1084,53 @@ addressbook_view_class_init (AddressbookViewClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 }
 
+static void
+source_selector_key_press_event_callback (GtkWidget *widget, GdkEventKey *event, AddressbookView *view)
+{
+	if (event->keyval == GDK_Delete) {
+		AddressbookViewPrivate *priv = view->priv;
+		ESource *selected_source;
+		EBook  *book;
+		GError *error = NULL;
+		GtkWindow *toplevel;
+
+		selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (priv->selector));
+		if (!selected_source) 
+			return;
+
+		toplevel = (GtkWindow *) gtk_widget_get_toplevel (priv->notebook);
+
+		if (e_error_run (toplevel, "addressbook:ask-delete-addressbook", 
+				e_source_peek_name(selected_source)) != GTK_RESPONSE_YES)
+			return;
+
+		/* Remove local data */
+		book = e_book_new (selected_source, &error);
+		if (book) {
+			if (e_book_remove (book, NULL)) {
+				if (e_source_selector_source_is_selected (E_SOURCE_SELECTOR (priv->selector),
+									  selected_source))
+					e_source_selector_unselect_source (E_SOURCE_SELECTOR (priv->selector),
+									   selected_source);
+		
+				e_source_group_remove_source (e_source_peek_group (selected_source), selected_source);
+			
+				e_source_list_sync (priv->source_list, NULL);
+			}
+			else {
+				e_error_run (toplevel, "addressbook:remove-addressbook", NULL);
+			}
+
+			g_object_unref (book);
+		}
+		else {
+			g_warning ("error removing addressbook : %s", error->message);
+			g_error_free (error);
+		}
+	}
+	return;
+}
+
 static void
 addressbook_view_init (AddressbookView *view)
 {
@@ -1155,12 +1208,15 @@ addressbook_view_init (AddressbookView *view)
 	g_signal_connect_object (priv->selector, "primary_selection_changed",
 				 G_CALLBACK (primary_source_selection_changed_callback),
 				 G_OBJECT (view), 0);
+	g_signal_connect_after (priv->selector, "key_press_event",
+		       		G_CALLBACK (source_selector_key_press_event_callback), 
+				G_OBJECT (view));
 	g_signal_connect_object (priv->selector, "popup_event",
 				 G_CALLBACK (popup_event_callback),
 				 G_OBJECT (view), 0);
 
 	load_primary_selection (view);
-	load_uri_for_selection (E_SOURCE_SELECTOR (priv->selector), view);
+	load_uri_for_selection (E_SOURCE_SELECTOR (priv->selector), view, TRUE);
 }
 
 static void
