@@ -141,6 +141,7 @@ static void page_dates_changed_cb (GtkObject *obj, CompEditorPageDates *dates, g
 
 static void obj_modified_cb (ECal *client, GList *objs, gpointer data);
 static void obj_removed_cb (ECal *client, GList *uids, gpointer data);
+static gboolean open_attachment (EAttachmentBar *bar, CompEditor *editor);
 
 G_DEFINE_TYPE (CompEditor, comp_editor, GTK_TYPE_DIALOG);
 
@@ -994,8 +995,24 @@ attachment_bar_changed_cb (EAttachmentBar *bar,
 
 }
 
-static	gboolean 
-attachment_bar_icon_clicked_cb (EAttachmentBar *bar, GdkEvent *event, CompEditor *editor)
+static void 	 
+attachment_expander_activate_cb (EExpander *expander, 	 
+				 void *data) 	 
+{ 	 
+	CompEditor *editor = COMP_EDITOR (data); 	 
+	gboolean show = e_expander_get_expanded (expander); 	 
+  	 
+	/* Update the expander label */ 	 
+	if (show) 	 
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (editor->priv->attachment_expander_label), 	 
+					          _("Hide Attachment _Bar")); 	 
+	else 	 
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (editor->priv->attachment_expander_label), 	 
+						  _("Show Attachment _Bar")); 	 
+}
+
+static gboolean 
+open_attachment (EAttachmentBar *bar, CompEditor *editor)
 {
 	GnomeIconList *icon_list;
 	GList *p;
@@ -1003,7 +1020,7 @@ attachment_bar_icon_clicked_cb (EAttachmentBar *bar, GdkEvent *event, CompEditor
 	char *attach_file_url;
 	GError *error = NULL;
 	
-	if (E_IS_ATTACHMENT_BAR (bar) && event->type == GDK_2BUTTON_PRESS) {
+	if (E_IS_ATTACHMENT_BAR (bar)) {
 		icon_list = GNOME_ICON_LIST (bar);
 		p = gnome_icon_list_get_selection (icon_list);
 		if (p) {
@@ -1039,8 +1056,27 @@ attachment_bar_icon_clicked_cb (EAttachmentBar *bar, GdkEvent *event, CompEditor
 		return FALSE;
 }
 
+static	gboolean 
+attachment_bar_icon_clicked_cb (EAttachmentBar *bar, GdkEvent *event, CompEditor *editor)
+{
+	if (E_IS_ATTACHMENT_BAR (bar) && event->type == GDK_2BUTTON_PRESS) 
+		if (open_attachment (bar, editor))
+				return TRUE;
+	return FALSE;
+}
+
 /* Callbacks.  */
 
+static void
+cab_open(EPopup *ep, EPopupItem *item, void *data)
+{
+	EAttachmentBar *bar = data;
+	CompEditor *editor = COMP_EDITOR (gtk_widget_get_toplevel (GTK_WIDGET (bar)));
+	
+	if (!open_attachment (bar, editor))
+		g_message ("\n Open failed");
+}
+
 static void
 cab_add(EPopup *ep, EPopupItem *item, void *data)
 {
@@ -1080,10 +1116,11 @@ cab_remove(EPopup *ep, EPopupItem *item, void *data)
 
 /* Popup menu handling.  */
 static EPopupItem cab_popups[] = {
-	{ E_POPUP_ITEM, "10.attach", N_("_Remove"), cab_remove, NULL, GTK_STOCK_REMOVE, E_CAL_POPUP_ATTACHMENTS_MANY | E_CAL_POPUP_ATTACHMENTS_MODIFY },
-	{ E_POPUP_ITEM, "20.attach", N_("_Properties"), cab_properties, NULL, GTK_STOCK_PROPERTIES, E_CAL_POPUP_ATTACHMENTS_ONE },
-	{ E_POPUP_BAR, "30.attach.00", NULL, NULL, NULL, NULL, E_CAL_POPUP_ATTACHMENTS_MANY|E_CAL_POPUP_ATTACHMENTS_ONE },
-	{ E_POPUP_ITEM, "30.attach.01", N_("_Add attachment..."), cab_add, NULL, GTK_STOCK_ADD, E_CAL_POPUP_ATTACHMENTS_MODIFY },
+	{ E_POPUP_ITEM, "10.attach", N_("_Open"), cab_open, NULL, GTK_STOCK_OPEN, E_CAL_POPUP_ATTACHMENTS_ONE},
+	{ E_POPUP_ITEM, "20.attach", N_("_Remove"), cab_remove, NULL, GTK_STOCK_REMOVE, E_CAL_POPUP_ATTACHMENTS_MANY | E_CAL_POPUP_ATTACHMENTS_MODIFY },
+	{ E_POPUP_ITEM, "30.attach", N_("_Properties"), cab_properties, NULL, GTK_STOCK_PROPERTIES, E_CAL_POPUP_ATTACHMENTS_ONE },
+	{ E_POPUP_BAR, "40.attach.00", NULL, NULL, NULL, NULL, E_CAL_POPUP_ATTACHMENTS_MANY|E_CAL_POPUP_ATTACHMENTS_ONE },
+	{ E_POPUP_ITEM, "40.attach.01", N_("_Add attachment..."), cab_add, NULL, GTK_STOCK_ADD, E_CAL_POPUP_ATTACHMENTS_MODIFY},
 };
 
 static void
@@ -1124,7 +1161,7 @@ cab_popup(EAttachmentBar *bar, GdkEventButton *event, int id)
 	ECalPopup *ecp;
 	ECalPopupTargetAttachments *t;
 	GtkMenu *menu;
-       CompEditor *editor = COMP_EDITOR (gtk_widget_get_toplevel (GTK_WIDGET (bar)));
+	CompEditor *editor = COMP_EDITOR (gtk_widget_get_toplevel (GTK_WIDGET (bar)));
 
         attachments = e_attachment_bar_get_attachment(bar, id);
 
@@ -1165,14 +1202,17 @@ button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
 	EAttachmentBar *bar = (EAttachmentBar *)widget;
 	GnomeIconList *icon_list = GNOME_ICON_LIST(widget);
-	int icon_number;
+	int icon_number = -1;
+	
 	if (event->button != 3)
 		return FALSE;
 	
-	icon_number = gnome_icon_list_get_icon_at (icon_list, event->x, event->y);
-	if (icon_number >= 0) {
-		gnome_icon_list_unselect_all(icon_list);
-		gnome_icon_list_select_icon (icon_list, icon_number);
+	if (!gnome_icon_list_get_selection (icon_list)) {
+		icon_number = gnome_icon_list_get_icon_at (icon_list, event->x, event->y);
+		if (icon_number >= 0) {
+			gnome_icon_list_unselect_all(icon_list);
+			gnome_icon_list_select_icon (icon_list, icon_number);
+		}
 	}
 
 	cab_popup(bar, event, icon_number);
@@ -1220,7 +1260,7 @@ setup_widgets (CompEditor *editor)
 	gtk_dialog_add_button  (GTK_DIALOG (editor), GTK_STOCK_OK, GTK_RESPONSE_OK);
 	gtk_dialog_add_button  (GTK_DIALOG (editor), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (editor), GTK_RESPONSE_OK, FALSE);
-
+	
 	g_signal_connect (editor, "response", G_CALLBACK (response_cb), editor);
 	g_signal_connect (editor, "delete_event", G_CALLBACK (delete_event_cb), editor);
 
@@ -1246,7 +1286,7 @@ setup_widgets (CompEditor *editor)
 	g_signal_connect (GNOME_ICON_LIST (priv->attachment_bar), "event",
 			  G_CALLBACK (attachment_bar_icon_clicked_cb), editor);			
 	priv->attachment_expander_label =
-		gtk_label_new_with_mnemonic (_("_Attachment Bar (drop attachments here)"));
+		gtk_label_new_with_mnemonic (_("Show Attachment _Bar"));
 	priv->attachment_expander_num = gtk_label_new ("");
 	gtk_label_set_use_markup (GTK_LABEL (priv->attachment_expander_num), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->attachment_expander_label), 0.0, 0.5);
@@ -1264,18 +1304,20 @@ setup_widgets (CompEditor *editor)
 	gtk_box_pack_start (GTK_BOX (expander_hbox), priv->attachment_expander_icon,
 			    TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (expander_hbox), priv->attachment_expander_num,
-			    FALSE, TRUE, 0);
+			    TRUE, TRUE, 0);
 	gtk_widget_show_all (expander_hbox);
 	gtk_widget_hide (priv->attachment_expander_icon);
 
-	gtk_box_pack_start (GTK_BOX (vbox), expander_hbox,
-			    FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->attachment_scrolled_window, FALSE, FALSE, GNOME_PAD_SMALL);
+	priv->attachment_expander = e_expander_new ("");
+	e_expander_set_label_widget (E_EXPANDER (priv->attachment_expander), expander_hbox);
+	atk_object_set_name (gtk_widget_get_accessible (priv->attachment_expander), _("Attachment Button: Press space key to toggle attachment bar"));
+	gtk_container_add (GTK_CONTAINER (priv->attachment_expander), priv->attachment_scrolled_window);
 
-	gtk_widget_show (priv->attachment_scrolled_window);
-	gtk_widget_show (expander_hbox);
-
-	
+	gtk_box_pack_start (GTK_BOX (vbox), priv->attachment_expander, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_widget_show (priv->attachment_expander);
+	e_expander_set_expanded (E_EXPANDER (priv->attachment_expander), FALSE); 	 
+	g_signal_connect_after (priv->attachment_expander, "activate", 	 
+				G_CALLBACK (attachment_expander_activate_cb), editor);
 }
 
 /* Object initialization function for the calendar component editor */
@@ -1691,7 +1733,7 @@ comp_editor_append_page (CompEditor *editor,
 	page_widget = comp_editor_page_get_widget (page);
 	g_assert (page_widget != NULL);
 
-	label_widget = gtk_label_new (label);
+	label_widget = gtk_label_new_with_mnemonic (label);
 
 	is_first_page = (priv->pages == NULL);
 
@@ -2089,6 +2131,7 @@ set_attachment_list (CompEditor *editor, GSList *attach_list)
 		}
 
 		e_attachment_bar_attach_mime_part ((EAttachmentBar *) editor->priv->attachment_bar, part);
+		e_expander_set_expanded (E_EXPANDER (editor->priv->attachment_expander), TRUE);
 
 		camel_object_unref (part);
 	}	
@@ -2422,7 +2465,7 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		CamelDataWrapper *wrapper;
 		CamelStreamMem *mstream;
 		unsigned char *buffer = NULL;
-		const char *desc;
+		const char *desc, *disp;
 
 		cal_mime_attach = g_malloc0 (sizeof (struct CalMimeAttach));
 		wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (l->data));
@@ -2441,6 +2484,10 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		cal_mime_attach->description = g_strdup (desc);
 		cal_mime_attach->content_type = g_strdup (camel_data_wrapper_get_mime_type (wrapper));
 		
+		disp = camel_mime_part_get_disposition ((CamelMimePart *)l->data);
+		if (disp && !g_ascii_strcasecmp(disp, "inline"))	
+			cal_mime_attach->disposition = TRUE;
+			
 		attach_list = g_slist_append (attach_list, cal_mime_attach);
 
 		camel_object_unref (mstream);
