@@ -32,13 +32,13 @@
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtktreeselection.h>
+#include <gdk/gdkkeysyms.h>
 #include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <gal/util/e-util.h>
-#include <gal/widgets/e-popup-menu.h>
-#include <gal/widgets/e-gui-utils.h>
-#include <widgets/misc/e-dateedit.h>
+#include <misc/e-gui-utils.h>
+#include <misc/e-dateedit.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-dialog-widgets.h>
 
@@ -50,7 +50,7 @@
 #include "comp-editor-util.h"
 #include "e-delegate-dialog.h"
 #include "meeting-page.h"
-
+#include "../e-cal-popup.h"
 
 /* Private part of the MeetingPage structure */
 struct _MeetingPagePrivate {
@@ -64,6 +64,7 @@ struct _MeetingPagePrivate {
 	EAccountList *accounts;
 	EMeetingAttendee *ia;
 	char *default_address;
+	char *user_add;
 	
 	/* Glade XML data */
 	GladeXML *xml;
@@ -80,6 +81,7 @@ struct _MeetingPagePrivate {
 	GtkWidget *remove;
 	GtkWidget *invite;
 	GtkWidget *att_label;
+	GtkWidget *org_label;
 
 	/* ListView stuff */
 	EMeetingStore *model;
@@ -95,30 +97,14 @@ struct _MeetingPagePrivate {
 
 
 
-static void meeting_page_class_init (MeetingPageClass *class);
-static void meeting_page_init (MeetingPage *mpage);
 static void meeting_page_finalize (GObject *object);
 
 static GtkWidget *meeting_page_get_widget (CompEditorPage *page);
 static void meeting_page_focus_main_widget (CompEditorPage *page);
 static gboolean meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp);
 static gboolean meeting_page_fill_component (CompEditorPage *page, ECalComponent *comp);
-
-static CompEditorPageClass *parent_class = NULL;
-
-
-
-/**
- * meeting_page_get_type:
- * 
- * Registers the #MeetingPage class if necessary, and returns the type ID
- * associated to it.
- * 
- * Return value: The type ID of the #MeetingPage class.
- **/
-
-E_MAKE_TYPE (meeting_page, "MeetingPage", MeetingPage, meeting_page_class_init, meeting_page_init,
-	     TYPE_COMP_EDITOR_PAGE);
+static void attendee_added_cb (EMeetingListView *emlv, EMeetingAttendee *attendee, gpointer user_data);
+G_DEFINE_TYPE (MeetingPage, meeting_page, TYPE_COMP_EDITOR_PAGE);
 
 /* Class initialization function for the task page */
 static void
@@ -130,8 +116,6 @@ meeting_page_class_init (MeetingPageClass *class)
 	editor_page_class = (CompEditorPageClass *) class;
 	object_class = (GObjectClass *) class;
 
-	parent_class = g_type_class_ref (TYPE_COMP_EDITOR_PAGE);
-
 	editor_page_class->get_widget = meeting_page_get_widget;
 	editor_page_class->focus_main_widget = meeting_page_focus_main_widget;
 	editor_page_class->fill_widgets = meeting_page_fill_widgets;
@@ -216,6 +200,7 @@ set_attendees (ECalComponent *comp, const GPtrArray *attendees)
 		
 	}
 	comp_attendees = g_slist_reverse (comp_attendees);
+	
 	e_cal_component_set_attendee_list (comp, comp_attendees);
 	
 	for (l = comp_attendees; l != NULL; l = l->next)
@@ -269,11 +254,15 @@ meeting_page_finalize (GObject *object)
 		priv->default_address = NULL;
 	}
 
+	if (priv->user_add) {
+		g_free (priv->user_add);
+		priv->user_add = NULL;
+	}
 	g_free (priv);
 	mpage->priv = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->finalize)
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
+	if (G_OBJECT_CLASS (meeting_page_parent_class)->finalize)
+		(* G_OBJECT_CLASS (meeting_page_parent_class)->finalize) (object);
 }
 
 
@@ -312,7 +301,17 @@ clear_widgets (MeetingPage *mpage)
 
 	priv = mpage->priv;
 
+	if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE) {
+		gtk_label_set_markup_with_mnemonic ((GtkLabel *)priv->att_label, _("<b>Dele_gatees</b>"));
+	}
+
+	if (e_cal_get_static_capability (COMP_EDITOR_PAGE (mpage)->client, CAL_STATIC_CAPABILITY_NO_ORGANIZER)) {
+		gtk_label_set_markup (GTK_LABEL (priv->org_label), _("<b>From:</b>"));
+		gtk_widget_hide (priv->existing_organizer_btn);
+	}
+				
 	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (priv->organizer)->entry), priv->default_address);
+
 	gtk_label_set_text (GTK_LABEL (priv->existing_organizer), _("None"));
 
 	gtk_widget_show (priv->organizer_table);
@@ -325,17 +324,25 @@ clear_widgets (MeetingPage *mpage)
 static void
 sensitize_widgets (MeetingPage *mpage)
 {
-	gboolean read_only, user_org;
+	gboolean read_only = FALSE;
 	MeetingPagePrivate *priv = mpage->priv;
+	GError *error = NULL;
+	guint32 flags;
+	gboolean delegate;
+	
+	flags = COMP_EDITOR_PAGE (mpage)->flags;
+	delegate = flags & COMP_EDITOR_PAGE_DELEGATE;
 
-	if (!e_cal_is_read_only (COMP_EDITOR_PAGE (mpage)->client, &read_only, NULL))
-		read_only = TRUE;
-
+	if (!e_cal_is_read_only (COMP_EDITOR_PAGE (mpage)->client, &read_only, &error)) {
+		if (error->code != E_CALENDAR_STATUS_BUSY)
+			read_only = TRUE;
+		g_error_free (error);
+	}	
 	gtk_widget_set_sensitive (priv->organizer, !read_only);
-	gtk_widget_set_sensitive (priv->existing_organizer_btn, !read_only);
-	gtk_widget_set_sensitive (priv->add, !read_only && priv->user_org);
-	gtk_widget_set_sensitive (priv->remove, !read_only && priv->user_org);
-	gtk_widget_set_sensitive (priv->invite, !read_only && priv->user_org);
+	gtk_widget_set_sensitive (priv->existing_organizer_btn, (!read_only && priv->user_org));
+	gtk_widget_set_sensitive (priv->add, (!read_only &&  priv->user_org) || delegate);
+	gtk_widget_set_sensitive (priv->remove, (!read_only &&  priv->user_org) || delegate);
+	gtk_widget_set_sensitive (priv->invite, (!read_only &&  priv->user_org) || delegate);
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->list_view), !read_only);
 }
 
@@ -352,6 +359,7 @@ meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 	priv->updating = TRUE;
 	
+	
 	/* Clean out old data */
 	if (priv->comp != NULL)
 		g_object_unref (priv->comp);
@@ -365,7 +373,9 @@ meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 	/* Component for cancellation */
 	priv->comp = e_cal_component_clone (comp);
-	
+
+	priv->user_add = itip_get_comp_attendee (comp, COMP_EDITOR_PAGE (mpage)->client);	
+
 	/* If there is an existing organizer show it properly */
 	if (e_cal_component_has_organizer (comp)) {
 		e_cal_component_get_organizer (comp, &organizer);
@@ -376,9 +386,6 @@ meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 			gtk_widget_hide (priv->organizer_table);
 			gtk_widget_show (priv->existing_organizer_table);
 			if (itip_organizer_is_user (comp, page->client)) {
-				gtk_widget_set_sensitive (priv->invite, TRUE);
-				gtk_widget_set_sensitive (priv->add, TRUE);
-				gtk_widget_set_sensitive (priv->remove, TRUE);
 				if (e_cal_get_static_capability (
 					    page->client,
 					    CAL_STATIC_CAPABILITY_ORGANIZER_NOT_EMAIL_ADDRESS))
@@ -395,10 +402,13 @@ meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 				priv->user_org = FALSE;
 			}
 			
-			if (organizer.cn != NULL)
+			if (e_cal_get_static_capability (COMP_EDITOR_PAGE (mpage)->client, CAL_STATIC_CAPABILITY_NO_ORGANIZER) && (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE))
+				string = g_strdup (priv->user_add);
+			else if ( organizer.cn != NULL)
 				string = g_strdup_printf ("%s <%s>", organizer.cn, strip);
 			else
 				string = g_strdup (strip);
+
 			gtk_label_set_text (GTK_LABEL (priv->existing_organizer), string);
 			g_free (string);
 
@@ -414,11 +424,15 @@ meeting_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 			e_meeting_attendee_set_address (priv->ia, g_strdup_printf ("MAILTO:%s", a->id->address));
 			e_meeting_attendee_set_cn (priv->ia, g_strdup (a->id->name));
-			e_meeting_attendee_set_status (priv->ia, ICAL_PARTSTAT_ACCEPTED);
+			if (page->client && e_cal_get_organizer_must_accept (page->client))
+				e_meeting_attendee_set_status (priv->ia, ICAL_PARTSTAT_NEEDSACTION);
+			else
+				e_meeting_attendee_set_status (priv->ia, ICAL_PARTSTAT_ACCEPTED);
 		}
 	}
 	
 	priv->updating = FALSE;
+	priv->user_org = page->flags & COMP_EDITOR_PAGE_USER_ORG;
 
 	sensitize_widgets (mpage);
 
@@ -470,7 +484,40 @@ meeting_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 			  _("At least one attendee is required."));
 		return FALSE;
 	}
-	set_attendees (comp, e_meeting_store_get_attendees (priv->model));
+	
+
+	if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE ) {
+		GSList *attendee_list, *l;
+		int i;
+		const GPtrArray *attendees = e_meeting_store_get_attendees (priv->model);
+
+		e_cal_component_get_attendee_list (priv->comp, &attendee_list);
+		
+		for (i = 0; i < attendees->len; i++) {
+			EMeetingAttendee *ia = g_ptr_array_index (attendees, i);
+			ECalComponentAttendee *ca;
+		
+			/* Remove the duplicate user from the component if present */
+			if (e_meeting_attendee_is_set_delto (ia)) {
+				for (l = attendee_list; l; l = l->next) {
+					ECalComponentAttendee *a = l->data;
+
+					if (g_str_equal (a->value, e_meeting_attendee_get_address (ia))) {
+						attendee_list = g_slist_remove (attendee_list, l->data);
+						break;
+					}
+				}
+			}
+			
+			ca = e_meeting_attendee_as_e_cal_component_attendee (ia);
+
+			attendee_list = g_slist_append (attendee_list, ca);
+		}
+		e_cal_component_set_attendee_list (comp, attendee_list);
+		e_cal_component_free_attendee_list (attendee_list);
+	} else 
+		set_attendees (comp, e_meeting_store_get_attendees (priv->model));
+
 	
 	return TRUE;
 }
@@ -526,6 +573,7 @@ get_widgets (MeetingPage *mpage)
 
 	/* Attendees Label */
 	priv->att_label = GW ("attendees-label");
+	priv->org_label = GW ("org-label");
 
 #undef GW
 
@@ -599,6 +647,11 @@ add_clicked_cb (GtkButton *btn, MeetingPage *mpage)
 	EMeetingAttendee *attendee;
 	
 	attendee = e_meeting_store_add_attendee_with_defaults (mpage->priv->model);
+
+	if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE) {
+		e_meeting_attendee_set_delfrom (attendee, g_strdup_printf ("MAILTO:%s", mpage->priv->user_add));
+	}
+
 	e_meeting_list_view_edit (mpage->priv->list_view, attendee);
 }
 
@@ -635,6 +688,7 @@ remove_attendee (MeetingPage *mpage, EMeetingAttendee *ia)
 {
 	MeetingPagePrivate *priv;
 	int pos = 0;
+	gboolean delegate = (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE);
 	
 	priv = mpage->priv;
 
@@ -652,7 +706,9 @@ remove_attendee (MeetingPage *mpage, EMeetingAttendee *ia)
 		ib = e_meeting_store_find_attendee (priv->model, e_meeting_attendee_get_delfrom (ia), &pos);
 		if (ib != NULL) {
 			e_meeting_attendee_set_delto (ib, NULL);
-			e_meeting_attendee_set_edit_level (ib,  E_MEETING_ATTENDEE_EDIT_FULL);
+			
+			if (!delegate) 
+				e_meeting_attendee_set_edit_level (ib,  E_MEETING_ATTENDEE_EDIT_FULL);
 		}		
 	}
 	
@@ -671,7 +727,7 @@ remove_attendee (MeetingPage *mpage, EMeetingAttendee *ia)
 
 		ia = ib;
 	}
-
+	
 	sensitize_widgets (mpage);
 }
 
@@ -693,39 +749,54 @@ remove_clicked_cb (GtkButton *btn, MeetingPage *mpage)
 	MeetingPagePrivate *priv;
 	EMeetingAttendee *ia;
 	GtkTreeSelection *selection;
+	GList *paths = NULL, *tmp;
 	GtkTreeIter iter;
-	GtkTreePath *path;
+	GtkTreePath *path = NULL;
 	gboolean valid_iter;
 	char *address;
 	
 	priv = mpage->priv;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->list_view));
-	if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
+	if (!(paths = gtk_tree_selection_get_selected_rows (selection, &(priv->model)))) {
 		g_warning ("Could not get a selection to delete.");
 		return;
 	}
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (priv->model), &iter);	
+	paths = g_list_reverse (paths);
 	
-	gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
-	ia = e_meeting_store_find_attendee (priv->model, address, NULL);
-	g_free (address);
-	if (!ia)
-		return;
-	
-	remove_attendee (mpage, ia);
+	for (tmp = paths; tmp; tmp=tmp->next) {
+		path = tmp->data;
+		
+		gtk_tree_model_get_iter (GTK_TREE_MODEL(priv->model), &iter, path);
 
+		gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
+		ia = e_meeting_store_find_attendee (priv->model, address, NULL);
+		g_free (address);
+		if (!ia) {
+			g_warning ("Cannot delete attendee\n");
+			continue;
+		} else if (e_meeting_attendee_get_edit_level (ia) != E_MEETING_ATTENDEE_EDIT_FULL) {
+			g_warning("Not enough rights to delete attendee: %s\n", e_meeting_attendee_get_address(ia));	
+			continue;
+		}
+		
+		remove_attendee (mpage, ia);
+	}
+	
 	/* Select closest item after removal */
 	valid_iter = gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
 	if (!valid_iter) {
 		gtk_tree_path_prev (path);
 		valid_iter = gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
 	}
-
-	if (valid_iter)
+	
+	if (valid_iter) {
+		gtk_tree_selection_unselect_all (selection);
 		gtk_tree_selection_select_iter (selection, &iter);
-
-	gtk_tree_path_free (path);
+	}
+	
+	g_list_foreach (paths, gtk_tree_path_free, NULL);
+	g_list_free (paths);
 }
 
 /* Function called to invite more people */
@@ -764,6 +835,39 @@ init_widgets (MeetingPage *mpage)
 
 	/* Contacts button */
 	g_signal_connect(priv->invite, "clicked", G_CALLBACK (invite_cb), mpage);
+
+	/* Meeting List View */
+	g_signal_connect (priv->list_view, "attendee_added", G_CALLBACK (attendee_added_cb), mpage);
+}
+
+static void
+attendee_added_cb (EMeetingListView *emlv, EMeetingAttendee *ia, gpointer user_data)
+{
+   MeetingPage *mpage = MEETING_PAGE (user_data);	
+   MeetingPagePrivate *priv;
+   gboolean delegate = (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE);
+
+   priv = mpage->priv;
+
+   if (delegate) {
+	   if (existing_attendee (ia, priv->comp))
+		   e_meeting_store_remove_attendee (priv->model, ia);
+	   else {
+		   if (!e_cal_get_static_capability (COMP_EDITOR_PAGE(mpage)->client, 
+					   CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY)) {
+			   const char *delegator_id = e_meeting_attendee_get_delfrom (ia);
+			   EMeetingAttendee *delegator;
+
+			   delegator = e_meeting_store_find_attendee (priv->model, delegator_id, NULL);
+			   e_meeting_attendee_set_delto (delegator, 
+					   g_strdup (e_meeting_attendee_get_address (ia)));
+
+			   gtk_widget_set_sensitive (priv->invite, FALSE);
+			   gtk_widget_set_sensitive (priv->add, FALSE);
+		   }
+	   }
+   }
+
 }
 
 static void
@@ -775,32 +879,42 @@ client_changed_cb (CompEditorPage *page, ECal *client, gpointer user_data)
 }
 
 static void
-popup_delete_cb (GtkWidget *widget, gpointer data) 
+popup_add_cb (EPopup *ep, EPopupItem *pitem, void *data)
 {
-	MeetingPage *mpage = MEETING_PAGE (data);
+	MeetingPage *mpage = data;
+
+	add_clicked_cb (NULL, mpage);
+}
+
+static void
+popup_delete_cb (EPopup *ep, EPopupItem *pitem, void *data)
+{
+	MeetingPage *mpage = data;
 	MeetingPagePrivate *priv;
 	
 	priv = mpage->priv;
 
-	remove_attendee_at_row (mpage, priv->row);
+	remove_clicked_cb (NULL, mpage);
 }
 
 enum {
-	CAN_DELEGATE = 2,
-	CAN_DELETE = 4
+	ATTENDEE_CAN_DELEGATE = 1<<1,
+	ATTENDEE_CAN_DELETE = 1<<2,
+	ATTENDEE_CAN_ADD = 1<<3,
+	ATTENDEE_LAST = 1<<4,
 };
 
-static EPopupMenu context_menu[] = {
-#if 0
-	E_POPUP_ITEM (N_("_Delegate To..."), G_CALLBACK (popup_delegate_cb),  CAN_DELEGATE),
-
-	E_POPUP_SEPARATOR,
-#endif
-	E_POPUP_ITEM (N_("_Remove"), G_CALLBACK (popup_delete_cb),   CAN_DELETE),
-	
-	E_POPUP_TERMINATOR
+static EPopupItem context_menu_items[] = {
+	{ E_POPUP_ITEM, "10.delete", N_("_Remove"), popup_delete_cb, NULL, GTK_STOCK_REMOVE, ATTENDEE_CAN_DELETE },
+	{ E_POPUP_ITEM, "15.add", N_("_Add "), popup_add_cb, NULL, GTK_STOCK_ADD },	
 };
 
+static void
+context_popup_free(EPopup *ep, GSList *items, void *data)
+{
+	g_slist_free(items);
+}
+
 static gint
 button_press_event (GtkWidget *widget, GdkEventButton *event, MeetingPage *mpage)
 {
@@ -810,8 +924,11 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, MeetingPage *mpage
 	GtkTreePath *path;
 	GtkTreeIter iter;
 	char *address;
-	int disable_mask = 0, hide_mask = 0;
-	
+	guint32 disable_mask = ~0;
+	GSList *menus = NULL;
+	ECalPopup *ep;
+	int i;
+
 	priv = mpage->priv;
 
 	/* only process right-clicks */
@@ -819,34 +936,84 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, MeetingPage *mpage
 		return FALSE;
 
 	/* only if we right-click on an attendee */
-	if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (priv->list_view), event->x, event->y, &path, NULL, NULL, NULL))
-		return FALSE;
-	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path))
-		return FALSE;
-	
-	gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
-	ia = e_meeting_store_find_attendee (priv->model, address, &priv->row);
-	g_free (address);
-	if (!ia)
-		return FALSE;
-	
- 	if (e_meeting_attendee_get_edit_level (ia) != E_MEETING_ATTENDEE_EDIT_FULL)
- 		disable_mask = CAN_DELETE;
- 
-	/* FIXME: if you enable Delegate, then change index to '1'.
-	 * (This has now been enabled). */
-	/* context_menu[1].pixmap_widget = gnome_stock_new_with_icon (GNOME_STOCK_MENU_TRASH); */
-	context_menu[0].pixmap_widget =
-	  gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
+	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (priv->list_view), event->x, event->y, &path, NULL, NULL, NULL)) {
+		GtkTreeSelection *selection;
 
-	menu = e_popup_menu_create (context_menu, disable_mask, hide_mask, mpage);
-	e_auto_kill_popup_menu_on_selection_done (menu);
+		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path)) {
+		
+			gtk_tree_model_get (GTK_TREE_MODEL (priv->model), &iter, E_MEETING_STORE_ADDRESS_COL, &address, -1);
+			ia = e_meeting_store_find_attendee (priv->model, address, &priv->row);
+			g_free (address);
+
+			if (ia) {
+				selection = gtk_tree_view_get_selection (priv->list_view);
+				gtk_tree_selection_unselect_all (selection);
+				gtk_tree_selection_select_path (selection, path);
+		
+ 				if (e_meeting_attendee_get_edit_level (ia) == E_MEETING_ATTENDEE_EDIT_FULL)
+ 					disable_mask &= ~ATTENDEE_CAN_DELETE;
+			}
+		}
+	}
+
+	if (GTK_WIDGET_IS_SENSITIVE(priv->add))
+		disable_mask &= ~ATTENDEE_CAN_ADD;
+	else if (priv->user_org)
+		disable_mask &= ~ATTENDEE_CAN_ADD;
+
+	ep = e_cal_popup_new("org.gnome.evolution.calendar.meeting.popup");
+
+	for (i=0;i<sizeof(context_menu_items)/sizeof(context_menu_items[0]);i++)
+		menus = g_slist_prepend(menus, &context_menu_items[i]);
 	
+	e_popup_add_items((EPopup *)ep, menus, NULL, context_popup_free, mpage);
+	menu = e_popup_create_menu_once((EPopup *)ep, NULL, disable_mask);
 	gtk_menu_popup (menu, NULL, NULL, NULL, NULL, event->button, event->time);
 
 	return TRUE;
 }
 
+static gboolean
+list_view_event (EMeetingListView *list_view, GdkEvent *event, MeetingPage *mpage) {
+	
+	MeetingPagePrivate *priv= mpage->priv;
+	
+	if (event->type == GDK_2BUTTON_PRESS && mpage->priv->user_org) {
+		EMeetingAttendee *attendee;
+	
+		attendee = e_meeting_store_add_attendee_with_defaults (priv->model);
+
+		if (COMP_EDITOR_PAGE (mpage)->flags & COMP_EDITOR_PAGE_DELEGATE) {
+			e_meeting_attendee_set_delfrom (attendee, g_strdup_printf ("MAILTO:%s", mpage->priv->user_add));
+		}
+
+		e_meeting_list_view_edit (mpage->priv->list_view, attendee);
+		return TRUE;
+	}
+
+	return FALSE;	
+}
+
+
+static gboolean
+list_key_press (EMeetingListView *list_view, GdkEventKey *event, MeetingPage *mpage)
+{
+	if (event->keyval == GDK_Delete) {
+		MeetingPagePrivate *priv;
+	
+		priv = mpage->priv;
+		remove_clicked_cb (NULL, mpage);
+
+		return TRUE;
+	} else if (event->keyval == GDK_Insert) {
+		add_clicked_cb (NULL, mpage);
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 /**
  * meeting_page_construct:
  * @mpage: An task details page.
@@ -861,11 +1028,13 @@ meeting_page_construct (MeetingPage *mpage, EMeetingStore *ems,
 			ECal *client)
 {
 	MeetingPagePrivate *priv;
-	char *backend_address;
+	char *backend_address = NULL;
 	EIterator *it;
 	EAccount *def_account;
 	GList *address_strings = NULL, *l;
 	GtkWidget *sw;
+	EAccount *a;
+	GtkTreeSelection *selection;
 	
 	priv = mpage->priv;
 
@@ -890,7 +1059,7 @@ meeting_page_construct (MeetingPage *mpage, EMeetingStore *ems,
 	for (it = e_list_get_iterator((EList *)priv->accounts);
 	     e_iterator_is_valid(it);
 	     e_iterator_next(it)) {
-		EAccount *a = (EAccount *)e_iterator_get(it);
+		a = (EAccount *)e_iterator_get(it);
 		char *full;
 		
 		full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
@@ -909,8 +1078,11 @@ meeting_page_construct (MeetingPage *mpage, EMeetingStore *ems,
 			priv->default_address = g_strdup (full);
 		}
 	}
+	
+	if (backend_address)
+		g_free (backend_address);
+
 	g_object_unref(it);
-	g_free (backend_address);
 
 	if (address_strings)
 		gtk_combo_set_popdown_strings (GTK_COMBO (priv->organizer), address_strings);
@@ -926,7 +1098,11 @@ meeting_page_construct (MeetingPage *mpage, EMeetingStore *ems,
 	priv->model = ems;
 
 	priv->list_view = e_meeting_list_view_new (priv->model); 
+	selection = gtk_tree_view_get_selection (priv->list_view);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	
 	g_signal_connect (G_OBJECT (priv->list_view), "button_press_event", G_CALLBACK (button_press_event), mpage);
+	g_signal_connect (G_OBJECT (priv->list_view), "event", G_CALLBACK (list_view_event), mpage);	
 
 	gtk_widget_show (GTK_WIDGET (priv->list_view));
 	sw = gtk_scrolled_window_new (NULL, NULL);
@@ -937,14 +1113,14 @@ meeting_page_construct (MeetingPage *mpage, EMeetingStore *ems,
 	gtk_box_pack_start (GTK_BOX (priv->list_box), sw, TRUE, TRUE, 0);
 	
 	/* Set the mnemonic widget for the Attendees label */
-	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->att_label),
-				       priv->list_view);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->att_label), GTK_WIDGET (priv->list_view));
 
 	/* Init the widget signals */
 	init_widgets (mpage);
 
 	g_signal_connect_after (G_OBJECT (mpage), "client_changed",
 				G_CALLBACK (client_changed_cb), NULL);
+	g_signal_connect (priv->list_view, "key_press_event", list_key_press, mpage);
 
 	return mpage;
 }
