@@ -134,7 +134,7 @@ task_editor_construct (TaskEditor *te, ECal *client)
 	gtk_object_sink (GTK_OBJECT (priv->task_page));
 	comp_editor_append_page (COMP_EDITOR (te), 
 				 COMP_EDITOR_PAGE (priv->task_page),
-				 _("Task"));
+				 _("_Task"));
 	g_signal_connect (G_OBJECT (priv->task_page), "client_changed",
 			  G_CALLBACK (client_changed_cb), te);
 
@@ -143,7 +143,7 @@ task_editor_construct (TaskEditor *te, ECal *client)
 	gtk_object_sink (GTK_OBJECT (priv->task_details_page));
 	comp_editor_append_page (COMP_EDITOR (te),
 				 COMP_EDITOR_PAGE (priv->task_details_page),
-				 _("Status"));
+				 _("_Status"));
 	
 	if (!e_cal_is_read_only (client, &read_only, NULL))
 			read_only = TRUE;
@@ -158,7 +158,7 @@ task_editor_construct (TaskEditor *te, ECal *client)
 		gtk_object_sink (GTK_OBJECT (priv->meet_page));
 		comp_editor_append_page (COMP_EDITOR (te),
 					 COMP_EDITOR_PAGE (priv->meet_page),
-					 _("Assignment"));
+					 _("Assig_nment"));
 	}
 
 	comp_editor_set_e_cal (COMP_EDITOR (te), client);
@@ -220,7 +220,7 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 		if (!priv->assignment_shown)
 			comp_editor_append_page (COMP_EDITOR (te),
 						 COMP_EDITOR_PAGE (priv->meet_page),
-						 _("Assignment"));
+						 _("Assig_nment"));
 
 		for (l = attendees; l != NULL; l = l->next) {
 			ECalComponentAttendee *ca = l->data;
@@ -377,7 +377,7 @@ show_assignment (TaskEditor *te)
 	if (!priv->assignment_shown) {
 		comp_editor_append_page (COMP_EDITOR (te),
 					 COMP_EDITOR_PAGE (priv->meet_page),
-					 _("Assignment"));
+					 _("Assig_nment"));
 		priv->assignment_shown = TRUE;
 
 		comp_editor_set_needs_send (COMP_EDITOR (te), priv->assignment_shown);
