@@ -54,7 +54,9 @@ typedef enum {
 	E_CAL_VIEW_MOVE_UP,
 	E_CAL_VIEW_MOVE_DOWN,
 	E_CAL_VIEW_MOVE_LEFT,
-	E_CAL_VIEW_MOVE_RIGHT
+	E_CAL_VIEW_MOVE_RIGHT,
+	E_CAL_VIEW_MOVE_PAGE_UP,
+	E_CAL_VIEW_MOVE_PAGE_DOWN	
 } ECalViewMoveDirection;
 
 #define E_CALENDAR_VIEW_EVENT_FIELDS \
