@@ -258,13 +258,11 @@ set_timezone (ETasks *tasks)
 	zone = calendar_config_get_icaltimezone ();
 	for (l = priv->clients_list; l != NULL; l = l->next) {
 		ECal *client = l->data;
-
-		if (e_cal_get_load_state (client) == E_CAL_LOAD_LOADED)
-			/* FIXME Error checking */
-			e_cal_set_default_timezone (client, zone, NULL);
+		/* FIXME Error checking */
+		e_cal_set_default_timezone (client, zone, NULL);
 	}
 
-	if (priv->default_client && e_cal_get_load_state (priv->default_client) == E_CAL_LOAD_LOADED)
+	if (priv->default_client) 
 		/* FIXME Error checking */
 		e_cal_set_default_timezone (priv->default_client, zone, NULL);
 
@@ -518,6 +516,7 @@ setup_widgets (ETasks *tasks)
 	ETasksPrivate *priv;
 	ETable *etable;
 	ECalModel *model;
+	gboolean state;
 
 	priv = tasks->priv;
 
@@ -586,7 +585,10 @@ setup_widgets (ETasks *tasks)
 	priv->preview = e_cal_component_preview_new ();
 	e_cal_component_preview_set_default_timezone (E_CAL_COMPONENT_PREVIEW (priv->preview), calendar_config_get_icaltimezone ());	
 	gtk_paned_add2 (GTK_PANED (priv->paned), priv->preview);
-	gtk_widget_show (priv->preview);
+	state = calendar_config_get_preview_state ();
+
+	if (state)
+		gtk_widget_show (priv->preview);
 
 	model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
 	g_signal_connect (G_OBJECT (model), "model_row_changed",
@@ -869,7 +871,6 @@ client_cal_opened_cb (ECal *ecal, ECalendarStatus status, ETasks *tasks)
 		model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
 		e_cal_model_add_client (model, ecal);
 
-		set_timezone (tasks);
 		set_status_message (tasks, NULL);
 		break;
 	case E_CALENDAR_STATUS_BUSY :
@@ -912,7 +913,6 @@ default_client_cal_opened_cb (ECal *ecal, ECalendarStatus status, ETasks *tasks)
 		g_signal_handlers_disconnect_matched (ecal, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, default_client_cal_opened_cb, NULL);
 		model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
 		
-		set_timezone (tasks);
 		e_cal_model_set_default_client (model, ecal);
 		set_status_message (tasks, NULL);
 		break;
@@ -946,9 +946,14 @@ static gboolean
 open_ecal (ETasks *tasks, ECal *cal, gboolean only_if_exists, open_func of)
 {
 	ETasksPrivate *priv;
+	icaltimezone *zone;
 
 	priv = tasks->priv;
 	
+	zone = calendar_config_get_icaltimezone ();
+	e_cal_set_default_timezone (priv->default_client, zone, NULL);
+
+	
 	set_status_message (tasks, _("Opening tasks at %s"), e_cal_get_uri (cal));
 
 	g_signal_connect (G_OBJECT (cal), "cal_opened", G_CALLBACK (of), tasks);
@@ -999,6 +1004,52 @@ e_tasks_new_task			(ETasks		*tasks)
 	comp_editor_focus (COMP_EDITOR (tedit));
 }
 
+void
+e_tasks_show_preview (ETasks *tasks, gboolean state)
+{
+	ETasksPrivate *priv;
+
+	g_return_if_fail (tasks != NULL);
+	g_return_if_fail (E_IS_TASKS (tasks));
+	priv = tasks->priv;
+
+	if (state) {
+		ECalModel *model;
+		ECalModelComponent *comp_data;
+		ECalComponent *comp;
+		ETable *etable;
+		const char *uid;
+		int n_selected;
+		
+		etable = e_table_scrolled_get_table (E_TABLE_SCROLLED (E_CALENDAR_TABLE (priv->tasks_view)->etable));
+		n_selected = e_table_selected_count (etable);
+		
+		if (n_selected != 1) {
+			e_cal_component_preview_clear (E_CAL_COMPONENT_PREVIEW (priv->preview));
+		} else {
+			model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
+			
+			comp_data = e_cal_model_get_component_at (model, e_table_get_cursor_row (etable));
+			comp = e_cal_component_new ();
+			e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
+		
+			e_cal_component_preview_display (E_CAL_COMPONENT_PREVIEW (priv->preview), comp_data->client, comp);
+			
+			e_cal_component_get_uid (comp, &uid);
+			if (priv->current_uid)
+				g_free (priv->current_uid);
+			priv->current_uid = g_strdup (uid);
+			
+			g_object_unref (comp);
+		}
+		gtk_widget_show (priv->preview);
+
+	} else	{
+		e_cal_component_preview_clear (E_CAL_COMPONENT_PREVIEW (priv->preview));		
+		gtk_widget_hide (priv->preview);
+	}
+}
+
 gboolean
 e_tasks_add_todo_source (ETasks *tasks, ESource *source)
 {
