@@ -436,10 +436,10 @@ edit_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static EPopupItem etc_source_popups[] = {
-	{ E_POPUP_ITEM, "10.new", N_("New Task List"), new_task_list_cb, NULL, "stock_todo", 0, 0 },
-	{ E_POPUP_ITEM, "15.copy", N_("Copy"), copy_task_list_cb, NULL, "stock_folder-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "20.delete", N_("Delete"), delete_task_list_cb, NULL, "stock_delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "30.properties", N_("Properties..."), edit_task_list_cb, NULL, "stock_folder-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, "10.new", N_("_New Task List"), new_task_list_cb, NULL, "stock_todo", 0, 0 },
+	{ E_POPUP_ITEM, "15.copy", N_("_Copy"), copy_task_list_cb, NULL, "stock_folder-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, "20.delete", N_("_Delete"), delete_task_list_cb, NULL, "stock_delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, "30.properties", N_("_Properties..."), edit_task_list_cb, NULL, "stock_folder-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
 };
 
 static void
@@ -863,6 +863,9 @@ setup_create_ecal (TasksComponent *component, TasksComponentView *component_view
 		
 	if (priv->create_ecal) {
 		icaltimezone *zone;
+		
+		zone = calendar_config_get_icaltimezone ();
+		e_cal_set_default_timezone (priv->create_ecal, zone, NULL);
 
 		if (!e_cal_open (priv->create_ecal, FALSE, NULL)) {
 			GtkWidget *dialog;
@@ -877,8 +880,6 @@ setup_create_ecal (TasksComponent *component, TasksComponentView *component_view
 			return NULL;
 		}
 
-		zone = calendar_config_get_icaltimezone ();
-		e_cal_set_default_timezone (priv->create_ecal, zone, NULL);
 	} else {
 		GtkWidget *dialog;
 			
@@ -909,6 +910,7 @@ create_new_todo (TasksComponent *task_component, gboolean is_assigned, TasksComp
 	TasksComponentPrivate *priv;
 	ECalComponent *comp;
 	TaskEditor *editor;
+	guint32 flags = 0;	
 	
 	priv = task_component->priv;
 	
@@ -916,7 +918,12 @@ create_new_todo (TasksComponent *task_component, gboolean is_assigned, TasksComp
 	if (!ecal)
 		return FALSE;
 
-	editor = task_editor_new (ecal, is_assigned);
+	if (is_assigned)
+		flags |= COMP_EDITOR_IS_ASSIGNED;
+	
+	flags |= COMP_EDITOR_NEW_ITEM | COMP_EDITOR_USER_ORG;
+
+	editor = task_editor_new (ecal, flags);
 	comp = cal_comp_task_new_with_defaults (ecal);
 
 	comp_editor_edit_comp (COMP_EDITOR (editor), comp);
