@@ -92,6 +92,16 @@
 #include "e-attachment.h"
 #include "e-attachment-bar.h"
 
+#ifdef G_OS_WIN32
+/* Undefine the similar macro from <pthread.h>,it doesn't check if
+ * localtime() returns NULL.
+ */
+#undef localtime_r
+
+/* The localtime() in Microsoft's C library is MT-safe */
+#define localtime_r(tp,tmp) (localtime(tp)?(*(tmp)=*localtime(tp),(tmp)):0)
+#endif
+
 #define d(x)
 
 #define EFHD_TABLE_OPEN "<table>"
@@ -409,6 +419,12 @@ void em_format_html_display_set_caret_mode(EMFormatHTMLDisplay *efhd, gboolean s
 	gtk_html_set_caret_mode(((EMFormatHTML *)efhd)->html, state);
 }
 
+EAttachmentBar *
+em_format_html_display_get_bar (EMFormatHTMLDisplay *efhd)
+{
+	return efhd->priv->attachment_bar;
+}
+
 void
 em_format_html_display_set_search(EMFormatHTMLDisplay *efhd, int type, GSList *strings)
 {
