@@ -428,13 +428,13 @@ get_addressbook_names_from_server (char *source_url)
 	const char *soap_port;
 	CamelURL *url;
 	gboolean remember;
-	char *failed_auth; 
+	char *failed_auth = NULL; 
 	char *prompt;
 	char *password_prompt;
 	char *uri;
 	const char *use_ssl;
 	const char *poa_address;
-	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER;
+	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET;
 
 	url = camel_url_new (source_url, NULL);
         if (url == NULL) {
@@ -456,26 +456,37 @@ get_addressbook_names_from_server (char *source_url)
 	else 
 		uri = g_strdup_printf ("http://%s:%s/soap", poa_address, soap_port);
 	
-	failed_auth = "";
 	cnc = NULL;
-        do {
-		password_prompt = g_strdup_printf (_("Enter password for %s (user %s)"),
-                                           poa_address, url->user);
-		prompt = g_strconcat (failed_auth, password_prompt, NULL);
-		g_free (password_prompt);
-		password = e_passwords_ask_password (prompt, "Groupwise", key, prompt,
-                                                     E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET, &remember,
-						     NULL);
-		g_free (prompt);
-		
-		if (!password) 
-			break;
+	do {
+		/*we have to uncache the password before prompting again*/
+		if (failed_auth) {
+			e_passwords_forget_password ("Groupwise", key);
+			password = NULL;
+		}
+
+		password = e_passwords_get_password ("Groupwise", key);
+		if (!password) {
+			password_prompt = g_strdup_printf (_("Enter password for %s (user %s)"),
+					poa_address, url->user);
+			prompt = g_strconcat (failed_auth ? failed_auth : "", password_prompt, NULL);
+			g_free (password_prompt);
+			password = e_passwords_ask_password (prompt, "Groupwise", key, prompt,
+					flags, &remember,
+					NULL);
+			g_free (prompt);
+
+			if (!password) 
+				break;
+		}
 		cnc = e_gw_connection_new (uri, url->user, password);
 		if (!E_IS_GW_CONNECTION(cnc) && use_ssl && g_str_equal (use_ssl, "when-possible")) {
 			char *http_uri = g_strconcat ("http://", uri + 8, NULL);
 			cnc = e_gw_connection_new (http_uri, url->user, password);
 			g_free (http_uri);
 		}
+
+		g_free (password);
+
 		failed_auth = _("Failed to authenticate.\n");
 		flags |= E_PASSWORDS_REPROMPT;
 	} while (cnc == NULL);
@@ -488,6 +499,8 @@ get_addressbook_names_from_server (char *source_url)
 	    
 		       
 	}
+	/*FIXME: This error message should be relocated to addressbook and should reflect 
+	 * that it actually failed to get the addressbooks*/
 	e_error_run (NULL, "mail:gw-accountsetup-error", poa_address, NULL);
 	return NULL;
 }
@@ -620,7 +633,12 @@ add_addressbook_sources (EAccount *account)
 		e_source_set_property (source, "auth-domain", "Groupwise");
 		e_source_set_property (source, "port", soap_port);
 		e_source_set_property(source, "user", url->user);
-		if (!strcmp (book_name, "Novell GroupWise Address Book"))
+		/* mark system address book for offline usage */
+		/* FIXME: add isPersonal flag to container and use that isFrequentContact
+		 * properties, instead of using writable to distinguish between the
+		 * system address book and other address books.
+		 */
+		if (!e_gw_container_get_is_writable (E_GW_CONTAINER(temp_list->data)))
 			e_source_set_property (source, "offline_sync", "1");
 		else
 			e_source_set_property (source, "offline_sync", 
@@ -797,7 +815,7 @@ account_added (EAccountList *account_listener, EAccount *account)
 	info->name = g_strdup (account->name);
 	info->source_url = g_strdup (account->source->url);
 	if (account->parent_uid) {
-		parent = e_account_list_find (account_listener, E_ACCOUNT_FIND_UID, account->parent_uid);
+		parent = (EAccount *)e_account_list_find (account_listener, E_ACCOUNT_FIND_UID, account->parent_uid);
 
 		if (!parent) 
 			return;
