@@ -36,8 +36,8 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkmain.h>
 
-#include <gal/widgets/e-unicode.h>
-#include <gal/widgets/e-gui-utils.h>
+#include <misc/e-unicode.h>
+#include <misc/e-gui-utils.h>
 
 #include <libgnome/gnome-i18n.h>
 
@@ -279,8 +279,9 @@ subitem_activated_cb (GtkWidget *widget, ESearchBar *esb)
 
 	esb->item_id = id;
 	esb->subitem_id = subid;
+	emit_search_activated (esb);
 
-	set_find_now_sensitive (esb, TRUE);
+	set_find_now_sensitive (esb, FALSE);
 	
 	gtk_widget_grab_focus (esb->entry);
 }
@@ -603,7 +604,7 @@ set_menu (ESearchBar *esb,
 		g_assert (items[i].subitems == NULL);
 
 		new_item = g_new (ESearchBarItem, 1);
-		new_item->text 	   = g_strdup (_(items[i].text));
+		new_item->text 	   = items[i].text ? g_strdup (_(items[i].text)) : NULL;
 		new_item->id   	   = items[i].id;
 		new_item->subitems = NULL;
 
